@@ -643,11 +643,20 @@ bool OGRGRASSLayer::ResetSequentialCursor()
 /************************************************************************/
 /*                           SetSpatialFilter                           */
 /************************************************************************/
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3, 11, 0)
+OGRErr OGRGRASSLayer::ISetSpatialFilter(int iGeomField,
+                                        const OGRGeometry *poGeomIn)
+#else
 void OGRGRASSLayer::SetSpatialFilter(OGRGeometry *poGeomIn)
+#endif
 {
     CPLDebug("GRASS", "SetSpatialFilter");
 
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3, 11, 0)
+    OGRLayer::ISetSpatialFilter(iGeomField, poGeomIn);
+#else
     OGRLayer::SetSpatialFilter(poGeomIn);
+#endif
 
     if (poGeomIn == NULL)
     {
@@ -657,10 +666,14 @@ void OGRGRASSLayer::SetSpatialFilter(OGRGeometry *poGeomIn)
             CPLFree(paSpatialMatch);
             paSpatialMatch = NULL;
         }
-        return;
     }
-
-    SetSpatialMatch();
+    else
+    {
+        SetSpatialMatch();
+    }
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3, 11, 0)
+    return OGRERR_NONE;
+#endif
 }
 
 /************************************************************************/
@@ -1071,7 +1084,12 @@ GIntBig OGRGRASSLayer::GetFeatureCount(int bForce)
 /*                                                                      */
 /*      Returns OGRERR_NONE/OGRRERR_FAILURE.                            */
 /************************************************************************/
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3, 11, 0)
+OGRErr OGRGRASSLayer::IGetExtent(int /*iGeomField */, OGREnvelope *psExtent,
+                                 bool /*bForce*/)
+#else
 OGRErr OGRGRASSLayer::GetExtent(OGREnvelope *psExtent, int /*bForce*/)
+#endif
 {
     struct bound_box box;
 
